ChapaWebView class

A widget for displaying the Chapa Web Checkout process in a web view.

Inheritance

Constructors

ChapaWebView({Key? key, required String url, required String fallBackNamedUrl, required String transactionReference, required String amountPaid, dynamic onPaymentFinished(String, String, String)?})
Constructor for ChapaWebView ignore: use_super_parameters

Properties

amountPaid → String
The amount paid for the transaction.
final
fallBackNamedUrl → String
The fallback route name to navigate to when exiting the payment page.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPaymentFinished ↔ dynamic Function(String, String, String)?
A callback triggered when the payment process is finished if the fallBackNamedUrl is Empty .
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionReference → String
The reference ID for the current transaction.s
final
url → String
The Checkout URL to be loaded in the web view.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ChapaWebView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited