data property
List
get
data
Getter for accessing the data part of the response body.
Implementation
List get data => body["body"];
Getter for accessing the data part of the response body.
List get data => body["body"];