hasMessageError method
Checks if there are any message errors in the API response.
Implementation
bool hasMessageError() => message!.isNotEmpty;
Checks if there are any message errors in the API response.
bool hasMessageError() => message!.isNotEmpty;