DirectChargeSuccessResponse class
Represents the response for a successful direct charge request.
Constructors
- DirectChargeSuccessResponse({String? message, String? status, Data? data})
- Creates a DirectChargeSuccessResponse instance.
-
DirectChargeSuccessResponse.fromJson(Map<
String, dynamic> json) - Initializes a DirectChargeSuccessResponse instance from a JSON map.
Properties
- data ↔ Data?
-
Data object containing additional information about the response.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
Message accompanying the success response.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
Status of the response.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited