HistoryData class

Represents historical data for a direct charge transaction.

Constructors

HistoryData({String? amount, String? charge, String? status, String? createdAt})
Creates an instance of HistoryData.
HistoryData.fromJson(Map<String, dynamic> json)
Initializes a HistoryData instance from a JSON map.

Properties

amount String?
Amount involved in the transaction.
getter/setter pair
charge String?
Charge applied to the transaction.
getter/setter pair
createdAt String?
Timestamp when the transaction was created.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Status of the transaction (e.g., "success", "failed").
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited