ValidateDirectChargeResponse class

Represents the response for validating a direct charge request.

Constructors

ValidateDirectChargeResponse({String? message, String? trxRef, String? processorId, required HistoryData? data})
Creates an instance of ValidateDirectChargeResponse.
ValidateDirectChargeResponse.fromJson(Map<String, dynamic> json)
Initializes a ValidateDirectChargeResponse instance from a JSON map.

Properties

data HistoryData?
Historical data related to the direct charge transaction.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
Message accompanying the validation response.
getter/setter pair
processorId String?
Processor ID of the direct charge transaction.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trxRef String?
Transaction reference associated with the direct charge.
getter/setter pair

Methods

getCreatedAtTime() DateTime
Retrieves the createdAt timestamp as a DateTime object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited