amountRequired constant
String
const amountRequired
Message displayed when the amount is missing or not provided.
Implementation
static const amountRequired = 'Amount is required';
Message displayed when the amount is missing or not provided.
static const amountRequired = 'Amount is required';