domain/custom-widget/contact_us library

Classes

ContactUs
A StatelessWidget that displays an error icon, a message, and a prompt for the user to contact support when something goes wrong in the app.