controller property
TextEditingController to manage the text field's content. It is used to read or modify the text inside the field.
Implementation
final TextEditingController controller;
TextEditingController to manage the text field's content. It is used to read or modify the text inside the field.
final TextEditingController controller;