enableBorder property
Whether to enable borders for the text field.
If set to true, the text field will display borders around it. Default is true.
Implementation
final bool enableBorder;
Whether to enable borders for the text field.
If set to true, the text field will display borders around it. Default is true.
final bool enableBorder;