filled property

bool filled
final

Whether the text field should have a background color.

If set to true, the field will be filled with the color specified in filledColor. Default is false.

Implementation

final bool filled;