hintText property
The hint text displayed when the field is empty.
This provides a description of the field's expected input. Default is an empty string.
Implementation
final String hintText;
The hint text displayed when the field is empty.
This provides a description of the field's expected input. Default is an empty string.
final String hintText;