inputFormatter property

List<TextInputFormatter>? inputFormatter
getter/setter pair

A list of input formatters to restrict or modify the input.

This allows customizing the input, such as restricting to certain characters.

Implementation

List<TextInputFormatter>? inputFormatter;