labelText property
The label text displayed above the field.
This provides a description for the field when it is focused. Default is an empty string.
Implementation
final String labelText;
The label text displayed above the field.
This provides a description for the field when it is focused. Default is an empty string.
final String labelText;