obscureText property

bool obscureText
final

Whether to obscure the text (e.g., for password fields).

If set to true, the text will be hidden and a password visibility icon will be shown. Default is false.

Implementation

final bool obscureText;