readOnly property
Whether the text field is read-only.
If set to true, the field will not allow the user to edit the text. Default is false.
Implementation
final bool readOnly;
Whether the text field is read-only.
If set to true, the field will not allow the user to edit the text. Default is false.
final bool readOnly;