textStyle property
The style of the text input itself.
This controls the appearance of the text entered by the user.
Implementation
final TextStyle? textStyle;
The style of the text input itself.
This controls the appearance of the text entered by the user.
final TextStyle? textStyle;