NetworkEvent class

Base class for all network events.

Extend this class to define specific events related to network changes or actions.

Implementers

Constructors

NetworkEvent()
Constructor for the base NetworkEvent class.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited