OnNetworkNotConnected class

Event triggered when the device is not connected to any network.

This event can be used to handle logic for offline scenarios

Inheritance

Constructors

OnNetworkNotConnected()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited