Validate class
Represents validation error details from the API.
This class includes information about validation errors such as invalid mobile numbers or other constraints.
Constructors
Properties
- data ↔ String?
-
Additional data related to the validation error.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mobile
↔ List<
String> ? -
A list of validation errors related to mobile numbers.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
The status of the validation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited