ApiError<U> class
Represents an error response from an API.
This class is used for handling errors returned by the API, typically with an error object and an associated HTTP status code.
U: The type of the error response body.
- Inheritance
-
- Object
- NetworkResponse<
dynamic, U> - ApiError
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited