NetworkResponse<T, U> class
abstract
Represents the base class for all network responses.
This abstract class is designed to handle both successful responses and different types of errors, providing a flexible way to manage API communication results.
T: The type of the successful response body.U: The type of the error response body.
- Implementers
Constructors
- NetworkResponse()
-
Base constructor for the
NetworkResponseclass.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited