Success<T> class
Represents a successful network response.
This class holds the response body returned from a successful API call.
T: The type of the response body.
- Inheritance
-
- Object
- NetworkResponse<
T, dynamic> - Success
Constructors
- Success({required T body})
-
Constructs a
Successresponse with the given body.const
Properties
- body → T
-
The response body from the successful API call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited