UnknownError class
Represents an unknown or unexpected error.
This class is used for errors that do not fall under specific categories, such as unhandled exceptions or unexpected issues.
error: A dynamic object providing details about the error.
- Inheritance
-
- Object
- NetworkResponse
- UnknownError
Constructors
- UnknownError({required dynamic error})
-
Constructs an
UnknownErrorresponse with the given error object.const
Properties
- error → dynamic
-
The unknown or unexpected error object.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited