Data class
Contains detailed data about a direct charge success response.
Constructors
- Data({VerificationType? authDataType, String? requestID, MetaData? meta, String? mode})
- Creates a Data instance.
-
Data.fromJson(Map<
String, dynamic> json) - Initializes a Data instance from a JSON map.
Properties
- authDataType ↔ VerificationType?
-
Type of verification/authentication required.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta ↔ MetaData?
-
Metadata containing additional information about the transaction.
getter/setter pair
- mode ↔ String?
-
Mode of the transaction.
getter/setter pair
- requestID ↔ String?
-
Request ID associated with the transaction.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited