domain/constants/enums library
Enums
- LocalPaymentMethods
- Enum representing various local payment methods available in the application.
- Mode
- Enum defining the modes in which the Merchant Status can operate.
- PaymentStatus
- Enum representing the status of a payment transaction.
- RequestType
- Enum defining the types of HTTP request methods used in API interactions.
- VerificationType
- Enum representing the types of verification methods for payment methods.