LocalPaymentMethods enum
Enum representing various local payment methods available in the application.
- Inheritance
- Available extensions
Values
- telebirr → const LocalPaymentMethods
-
Represents the Telebirr payment method.
- mpessa → const LocalPaymentMethods
-
Represents the M-Pesa payment method.
- cbebirr → const LocalPaymentMethods
-
Represents the CBE Birr payment method.
- ebirr → const LocalPaymentMethods
-
Represents the E-Birr payment method.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
displayName(
) → String -
Available on LocalPaymentMethods, provided by the PaymentTypeExtension extension
Returns the display name of the payment method. -
iconPath(
) → String -
Available on LocalPaymentMethods, provided by the PaymentTypeExtension extension
Returns the icon path for the payment method. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value(
) → String -
Available on LocalPaymentMethods, provided by the PaymentTypeExtension extension
Returns the string value of the payment method. -
verificationType(
) → VerificationType -
Available on LocalPaymentMethods, provided by the PaymentTypeExtension extension
Returns theVerificationTypeassociated with the payment method.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LocalPaymentMethods> - A constant List of the values in this enum, in order of their declaration.