filled property
Whether the text field should have a background color.
If set to true, the field will be filled with the color specified in filledColor. Default is false.
Implementation
final bool filled;
Whether the text field should have a background color.
If set to true, the field will be filled with the color specified in filledColor. Default is false.
final bool filled;