inputFormatter property
A list of input formatters to restrict or modify the input.
This allows customizing the input, such as restricting to certain characters.
Implementation
List<TextInputFormatter>? inputFormatter;
A list of input formatters to restrict or modify the input.
This allows customizing the input, such as restricting to certain characters.
List<TextInputFormatter>? inputFormatter;