minLine property
The minimum number of lines the text field can have.
This is useful for multi-line text inputs and can ensure the field is not too small.
Implementation
final int minLine;
The minimum number of lines the text field can have.
This is useful for multi-line text inputs and can ensure the field is not too small.
final int minLine;