suffix property
A custom widget to be displayed as a suffix icon.
If not provided, the widget will display a visibility toggle for password fields.
Implementation
final Widget? suffix;
A custom widget to be displayed as a suffix icon.
If not provided, the widget will display a visibility toggle for password fields.
final Widget? suffix;