textInputAction property
The action to be taken when the user submits the text.
This controls the behavior of the keyboard when the user presses the "Done" button or similar. Default is TextInputAction.done.
Implementation
TextInputAction textInputAction;