PaymentMethodsCustomBuilderView class
A custom widget for displaying payment methods in a grid or horizontal list.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PaymentMethodsCustomBuilderView
Constructors
-
PaymentMethodsCustomBuilderView({Key? key, required bool? showPaymentMethodsOnGridView, required List<
LocalPaymentMethods> availablePaymentMethods, required dynamic onPressed(LocalPaymentMethods), required LocalPaymentMethods? selectedPaymentMethod}) - Constructor
Properties
-
availablePaymentMethods
→ List<
LocalPaymentMethods> -
A list of available payment methods to be displayed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed ↔ dynamic Function(LocalPaymentMethods)
-
A callback function that is triggered when a payment method is selected
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedPaymentMethod ↔ LocalPaymentMethods?
-
The currently selected payment method. Used to highlight
getter/setter pair
- showPaymentMethodsOnGridView → bool?
-
A flag to determine whether the payment methods
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PaymentMethodsCustomBuilderView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited